from setuptools import setup

setup(name='distri_aws_udacity',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['distri_aws_udacity'],
      author="Utkarsh Gupta",
      author_email="utkarshgupt2000@gmail.com",
      zip_safe=False)
